@@ -1,9 +1,12 @@
 package Dist::Zilla::Plugin::MapMetro::MakeGraphViz;
-$Dist::Zilla::Plugin::MapMetro::MakeGraphViz::VERSION = '0.1100';
+
 use strict;
 use warnings;
 use 5.14.0;
 
+our $VERSION = '0.1101'; # VERSION
+# ABSTRACT: Automatically creates a GraphViz2 visualisation of a Metro::Map map
+
 use Moose;
 use namespace::sweep;
 use Path::Tiny;
@@ -144,8 +147,8 @@ sub after_build {
         );
         $viz->add_edge(from => $invisible_station_id,
                        to => $hidden->{'station_id'},
-                       color => '#ff0000',
-                       penwidth => $ENV{'MMVIZDEBUG'} ? 1 : 0,
+                       color => $ENV{'MMVIZDEBUG'} ? '#ff0000' : '#ffffff',
+                       penwidth => 5,
                        len => 1,
                        weight => 100,
         );
@@ -208,11 +211,17 @@ sub get_pos_for {
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-Dist::Zilla::Plugin::MapMetro::MakeGraphViz - Automatically creates a GraphViz2 visualisation of a map
+Dist::Zilla::Plugin::MapMetro::MakeGraphViz - Automatically creates a GraphViz2 visualisation of a Metro::Map map
+
+=head1 VERSION
+
+Version 0.1101, released 2015-01-16.
 
 =head1 SYNOPSIS
 
@@ -225,23 +234,45 @@ This L<Dist::Zilla> plugin creates a L<GraphViz2> visualisation of a L<Map::Metr
 
 =head1 SEE ALSO
 
+=over 4
+
+=item *
+
+L<Task::MapMetro::Dev> - Map::Metro development tools
+
+=item *
+
 L<Map::Metro>
 
+=item *
+
 L<Map::Metro::Plugin::Map>
 
+=item *
+
 L<Map::Metro::Plugin::Map::Stockholm> - An example
 
+=back
+
+cut
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Dist-Zilla-Plugin-mapMetro-MakeGraphViz>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Dist-Zilla-Plugin-MapMetro-MakeGraphViz>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
